This function cleans variables with special characters by splitting values into separate variables that are separated by special characters by applying the function within a dataset.

apply_handle_splits(data, special_cols, sep = ";")

Arguments

data

An RSA-911 dataset.

special_cols

A character vector of the names of variables with special character values in the dataset.

sep

The special character that is separating values within the variable.

Value

The cleaned RSA-911 dataset, with new variables that contain the cleaned, separated values without special characters.