This function cleans and shortens name variables, for example, to applied on a variable such as Provider.

handle_abbrev(x)

Arguments

x

The name variable.

Value

The cleaned name variable, with abbreviated values.