handle_splits.RdThis function cleans variables with special characters by splitting values into separate variables that are separated by special characters.
handle_splits(var, var_name, sep = ";")An RSA-911 special character variable (vector) to be cleaned.
A character vector of the name of the variable to be cleaned.
The special character that is separating values within the variable.
The new variables derived from the inputted variable. They contain the cleaned, separated values without special characters.