This function merges cleaned Utah scores data with cleaned Utah RSA-911 Data.

merge_scores(
  quarterly_data,
  scores_data,
  quarterly_id = "Participant_ID",
  scores_id = "Participant_ID"
)

Arguments

quarterly_data

The cleaned RSA-911 dataset.

scores_data

The cleaned scores dataset.

quarterly_id

A string for the variable name corresponding to participant ID in the cleaned RSA-911 dataset. Defaults to "Participant_ID".

scores_id

A string for the variable name corresponding to participant ID in the cleaned scores dataset. Defaults to "Participant_ID".

Value

A data frame with one row per participant.