This function cleans primary and secondary disability variables with special characters by splitting impairment and cause values into separate variables that are separated by special characters.

separate_disability(df)

Arguments

df

An RSA-911 dataset to be cleaned.

Value

The cleaned RSA-911 dataset, with new, separate variables for primary and secondary cause and impairment, without special characters.