This function produces tailored visualizations for a TRT scores dataset in one step.

visualize_scores(
  data,
  option = c("overview", "across_service", "across_provider"),
  one_window = FALSE
)

Arguments

data

A cleaned TRT scores dataset. Apply clean_scores function first.

option

The selected visual analysis option. The options are "overview": "across_service": "across_provider":

one_window

Whether or not the user wants the visuals to be displayed in one plotting window, or spread across multiple plot windows. Defaults to FALSE.

Value

The appropriate plots for the chosen visual analysis.