apply_handle_splits.RdThis function cleans variables with special characters by splitting values into separate variables that are separated by special characters by applying the function within a dataset.
apply_handle_splits(data, special_cols, sep = ";")An RSA-911 dataset.
A character vector of the names of variables with special character values in the dataset.
The special character that is separating values within the variable.
The cleaned RSA-911 dataset, with new variables that contain the cleaned, separated values without special characters.