clean_provider.RdThis function cleans a scores dataset, based on the standard data structure, returning a dataset focused on provider-variable analysis.
clean_provider(
data,
state_filter = NULL,
id_col = NULL,
remove_questions = TRUE,
condense = FALSE,
clean_id = TRUE
)The TRT scores dataset.
A character vector identifying the state(s) of interest. Defaults to NULL.
Differing variable naming structure for participant ID. (Eg. "X", or another name not similar to "participant" or "ID".) Defaults to NULL.
Defaults to TRUE. When TRUE, removes question item variables.
Defaults to FALSE. When true, take medians across participants in order to keep only unique combinations of provider and service.
TRUE or FALSE. Defaults to TRUE, when TRUE, rows where participant ID is missing are removed.
A cleaned data frame, including only provider-relevant variables, restructured.