handle_abbrev.Rd
This function cleans and shortens name variables, for example, to applied on a variable such as Provider.
handle_abbrev(x)
The name variable.
The cleaned name variable, with abbreviated values.