merge_scores.RdThis function merges cleaned Utah scores data with cleaned Utah RSA-911 Data.
merge_scores(
quarterly_data,
scores_data,
quarterly_id = "Participant_ID",
scores_id = "Participant_ID"
)The cleaned RSA-911 dataset.
The cleaned scores dataset.
A string for the variable name corresponding to participant ID in the cleaned RSA-911 dataset. Defaults to "Participant_ID".
A string for the variable name corresponding to participant ID in the cleaned scores dataset. Defaults to "Participant_ID".
A data frame with one row per participant.