visualize_metadata.RdThis function produces tailored visualizations for RSA and TRT scores metadata in one step.
visualize_metadata(
data,
option = c("general_demo", "investigate_scores", "investigate_wage",
"investigate_employment"),
one_window = FALSE
)A cleaned metadata dataset. Apply clean_utah function first.
The selected visual analysis option. The options are "general_demo": "investigate_scores": "investigate_wage": "investigate_employment":
Whether or not the user wants the visuals to be displayed in one plotting window, or spread across multiple plot windows. Defaults to FALSE.
The appropriate plots for the chosen visual analysis.